@@ -1,5 +1,5 @@
 package Lingua::EN::Fractions;
-$Lingua::EN::Fractions::VERSION = '0.06';
+$Lingua::EN::Fractions::VERSION = '0.08';
 use 5.008;
 use strict;
 use warnings;
@@ -190,7 +190,7 @@ operations on them.
 
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/Lingua-EN-Fractions>
+L<https://github.com/neilb/Lingua-EN-Fractions>
 
 =head1 AUTHOR
 
